@@ -78,6 +78,11 @@ GAP_STATIC_ASSERT(sizeof(void *) == sizeof(struct OpaqueBag),
 // #define VALIDATE_MARKING
 
 
+// if USE_GAP_INSIDE_JULIA is defined, then some hacks which are needed
+// to make julia-inside-gap work are disabled. This is mainly for use in
+// the GAP.jl package.
+// #define USE_GAP_INSIDE_JULIA
+
 // Comparing pointers in C without triggering undefined behavior
 // can be difficult. As the GC already assumes that the memory
 // range goes from 0 to 2^k-1 (region tables), we simply convert
@@ -104,30 +109,7 @@ static inline int lt_ptr(void * a, void * b)
     return (uintptr_t)a < (uintptr_t)b;
 }
 
-#if 0
-static inline int gt_ptr(void * a, void * b)
-{
-    return (uintptr_t)a > (uintptr_t)b;
-}
-
-static inline void *max_ptr(void *a, void *b)
-{
-    if ((uintptr_t) a > (uintptr_t) b)
-        return a;
-    else
-        return b;
-}
-
-static inline void *min_ptr(void *a, void *b)
-{
-    if ((uintptr_t) a < (uintptr_t) b)
-        return a;
-    else
-        return b;
-}
-#endif
-
-/* align pointer to full word if mis-aligned */
+// align pointer to full word if mis-aligned
 static inline void * align_ptr(void * p)
 {
     uintptr_t u = (uintptr_t)p;
@@ -205,33 +187,26 @@ static void JFinalizer(jl_value_t * obj)
         TabFreeFuncBags[tnum]((Bag)&contents);
 }
 
-static jl_datatype_t * datatype_mptr;
-static jl_datatype_t * datatype_bag;
-static jl_datatype_t * datatype_largebag;
+static jl_datatype_t * DatatypeGapObj;
+static jl_datatype_t * DatatypeSmallBag;
+static jl_datatype_t * DatatypeLargeBag;
+#if !defined(USE_GAP_INSIDE_JULIA)
 static Bag *           GapStackBottom;
-static jl_ptls_t       JuliaTLS, SaveTLS;
-static BOOL            is_threaded;
 static jl_task_t *     RootTaskOfMainThread;
-static size_t          max_pool_obj_size;
-static UInt            YoungRef;
+#endif
+static size_t          MaxPoolObjSize;
 static int             FullGC;
-static UInt            startTime, totalTime;
+static UInt            StartTime, TotalTime;
 
+typedef struct {
+    jl_ptls_t ptls;
+    UInt youngRef;
+} MarkData;
 
 #if JULIA_VERSION_MAJOR == 1 && JULIA_VERSION_MINOR == 7
 JL_DLLEXPORT void *jl_get_ptls_states(void);
 #endif
 
-void SetJuliaTLS(void)
-{
-    // In Julia >= 1.7 we are supposed to use `jl_get_current_task()->ptls`
-    // instead of calling `jl_get_ptls_states`. But then we depend on the
-    // offset of the member `ptls` of struct `jl_task_t` not changing, so
-    // calling jl_get_ptls_states() is safer.
-    JuliaTLS = jl_get_ptls_states();
-//    JuliaTLS = jl_get_current_task()->ptls;
-}
-
 typedef void * Ptr;
 
 #define ELEM_TYPE Ptr
@@ -250,23 +225,23 @@ static Int          GlobalCount;
 
 /****************************************************************************
 **
-*F  AllocateBagMemory( <type>, <size> )
+*F  AllocateBagMemory( <ptls>, <type>, <size> )
 **
 **  Allocate memory for a new bag.
 **/
-static void * AllocateBagMemory(UInt type, UInt size)
+static void * AllocateBagMemory(jl_ptls_t ptls, UInt type, UInt size)
 {
     // HOOK: return `size` bytes memory of TNUM `type`.
     void * result;
-    if (size <= max_pool_obj_size) {
-        result = (void *)jl_gc_alloc_typed(JuliaTLS, size, datatype_bag);
+    if (size <= MaxPoolObjSize) {
+        result = (void *)jl_gc_alloc_typed(ptls, size, DatatypeSmallBag);
     }
     else {
-        result = (void *)jl_gc_alloc_typed(JuliaTLS, size, datatype_largebag);
+        result = (void *)jl_gc_alloc_typed(ptls, size, DatatypeLargeBag);
     }
     memset(result, 0, size);
     if (TabFreeFuncBags[type])
-        jl_gc_schedule_foreign_sweepfunc(JuliaTLS, (jl_value_t *)result);
+        jl_gc_schedule_foreign_sweepfunc(ptls, (jl_value_t *)result);
     return result;
 }
 
@@ -282,9 +257,9 @@ static void * AllocateBagMemory(UInt type, UInt size)
 **  the second time raises a warning, because a non-default marking function
 **  is being replaced.
 */
-static void MarkAllSubBagsDefault(Bag bag)
+static void MarkAllSubBagsDefault(Bag bag, void * ref)
 {
-    MarkArrayOfBags(CONST_PTR_BAG(bag), SIZE_BAG(bag) / sizeof(Bag));
+    MarkArrayOfBags(CONST_PTR_BAG(bag), SIZE_BAG(bag) / sizeof(Bag), ref);
 }
 
 TNumMarkFuncBags TabMarkFuncBags[NUM_TYPES];
@@ -296,15 +271,15 @@ void InitMarkFuncBags(UInt type, TNumMarkFuncBags mark_func)
     TabMarkFuncBags[type] = mark_func;
 }
 
-static inline int JMarkTyped(void * obj, jl_datatype_t * ty)
+static inline int JMarkTyped(jl_ptls_t ptls, void * obj, jl_datatype_t * ty)
 {
     // only traverse objects internally used by GAP
     if (!jl_typeis(obj, ty))
         return 0;
-    return jl_gc_mark_queue_obj(JuliaTLS, (jl_value_t *)obj);
+    return jl_gc_mark_queue_obj(ptls, (jl_value_t *)obj);
 }
 
-static inline int JMark(void * obj)
+static inline int JMark(jl_ptls_t ptls, void * obj)
 {
 #ifdef VALIDATE_MARKING
     // Validate that `obj` is still allocated and not on a
@@ -316,10 +291,11 @@ static inline int JMark(void * obj)
     if (!jl_typeis(ty, jl_datatype_type))
         abort();
 #endif
-    return jl_gc_mark_queue_obj(JuliaTLS, (jl_value_t *)obj);
+    return jl_gc_mark_queue_obj(ptls, (jl_value_t *)obj);
 }
 
-void MarkJuliaObjSafe(void * obj)
+// the following is used by JuliaInterface
+void MarkJuliaObjSafe(void * obj, void * ref)
 {
     if (!obj)
         return;
@@ -331,17 +307,17 @@ void MarkJuliaObjSafe(void * obj)
         return;
     if (!jl_typeis(ty, jl_datatype_type))
         return;
-    if (jl_gc_mark_queue_obj(JuliaTLS, (jl_value_t *)obj))
-        YoungRef++;
+    if (jl_gc_mark_queue_obj(((MarkData *)ref)->ptls, (jl_value_t *)obj))
+        ((MarkData *)ref)->youngRef++;
 }
 
-
-void MarkJuliaObj(void * obj)
+// the following is used by JuliaInterface
+void MarkJuliaObj(void * obj, void * ref)
 {
     if (!obj)
         return;
-    if (JMark(obj))
-        YoungRef++;
+    if (JMark(((MarkData *)ref)->ptls, obj))
+        ((MarkData *)ref)->youngRef++;
 }
 
 
@@ -399,16 +375,16 @@ void MarkJuliaObj(void * obj)
 // the stack buffer or receive a segmentation fault due to hitting a guard
 // page.
 
-static void TryMark(void * p)
+static void TryMark(jl_ptls_t ptls, void * p)
 {
     jl_value_t * p2 = jl_gc_internal_obj_base_ptr(p);
-    if (p2 && jl_typeis(p2, datatype_mptr)) {
+    if (p2 && jl_typeis(p2, DatatypeGapObj)) {
 #ifndef REQUIRE_PRECISE_MARKING
         // Prepopulate the mark cache with references we know
         // are valid and in current use.
         MarkCache[MARK_HASH((UInt)p2)] = (Bag)p2;
 #endif
-        JMark(p2);
+        JMark(ptls, p2);
     }
 }
 
@@ -422,7 +398,7 @@ static void FindLiveRangeReverse(PtrArray * arr, void * start, void * end)
     while (!lt_ptr(q, p)) {
         void * addr = *(void **)q;
         if (addr && jl_gc_internal_obj_base_ptr(addr) == addr &&
-            jl_typeis(addr, datatype_mptr)) {
+            jl_typeis(addr, DatatypeGapObj)) {
             PtrArrayAdd(arr, addr);
         }
         q -= C_STACK_ALIGN;
@@ -439,10 +415,10 @@ static int CmpTaskInfo(TaskInfo i1, TaskInfo i2)
     return cmp_ptr(i1.task, i2.task);
 }
 
-static void MarkFromList(PtrArray * arr)
+static void MarkFromList(jl_ptls_t ptls, PtrArray * arr)
 {
     for (Int i = 0; i < arr->len; i++) {
-        JMark(arr->items[i]);
+        JMark(ptls, arr->items[i]);
     }
 }
 
@@ -485,7 +461,7 @@ static void SafeScanTaskStack(PtrArray * stack, void * start, void * end)
         // The start of the stack buffer may be protected with guard
         // pages; accessing these results in segmentation faults.
         // Julia catches those segmentation faults and longjmps to
-        // JuliaTLS->safe_restore; we use this mechanism to abort stack
+        // a safe_restore function pointer; we use this mechanism to abort stack
         // scanning when a protected page is hit. For this to work, we
         // must scan the stack from the end of the stack buffer towards
         // the start (i.e. in the direction in which the stack grows).
@@ -533,10 +509,10 @@ ScanTaskStack(int rescan, jl_task_t * task, void * start, void * end)
             PtrArraySetLen(stack, p + 1);
         }
     }
-    MarkFromList(stack);
+    MarkFromList(jl_get_ptls_states(), stack);
 }
 
-static NOINLINE void TryMarkRange(void * start, void * end)
+static NOINLINE void TryMarkRange(jl_ptls_t ptls, void * start, void * end)
 {
     if (lt_ptr(end, start)) {
         SWAP(void *, start, end);
@@ -546,11 +522,11 @@ static NOINLINE void TryMarkRange(void * start, void * end)
     while (lt_ptr(p, q)) {
         void * addr = *(void **)p;
         if (addr) {
-            TryMark(addr);
+            TryMark(ptls, addr);
 #ifdef MARKING_STRESS_TEST
             for (int j = 0; j < 1000; ++j) {
                 UInt val = (UInt)addr + rand() - rand();
-                TryMark((void *)val);
+                TryMark(ptls, (void *)val);
             }
 #endif
         }
@@ -560,7 +536,7 @@ static NOINLINE void TryMarkRange(void * start, void * end)
 
 BOOL IsGapObj(void * p)
 {
-    return jl_typeis(p, datatype_mptr);
+    return jl_typeis(p, DatatypeGapObj);
 }
 
 void CHANGED_BAG(Bag bag)
@@ -570,6 +546,7 @@ void CHANGED_BAG(Bag bag)
 
 static void GapRootScanner(int full)
 {
+    jl_ptls_t   ptls  = jl_get_ptls_states();
     jl_task_t * task = (jl_task_t *)jl_get_current_task();
     size_t      size;
     int         tid;    // unused
@@ -578,6 +555,8 @@ static void GapRootScanner(int full)
     // current_task != root_task.
     char * stackend = (char *)jl_task_stack_buffer(task, &size, &tid);
     stackend += size;
+
+#if !defined(USE_GAP_INSIDE_JULIA)
     // The following test overrides the stackend if the following two
     // conditions hold:
     //
@@ -592,6 +571,7 @@ static void GapRootScanner(int full)
     if (task == RootTaskOfMainThread) {
         stackend = (char *)GapStackBottom;
     }
+#endif
 
     // Allow installing a custom marking function. This is used for
     // integrating GAP (possibly linked as a shared library) with other code
@@ -605,14 +585,14 @@ static void GapRootScanner(int full)
     // references stored in registers.
     jmp_buf registers;
     _setjmp(registers);
-    TryMarkRange(registers, (char *)registers + sizeof(jmp_buf));
-    TryMarkRange((char *)registers + sizeof(jmp_buf), stackend);
+    TryMarkRange(ptls, registers, (char *)registers + sizeof(jmp_buf));
+    TryMarkRange(ptls, (char *)registers + sizeof(jmp_buf), stackend);
 
     // mark all global objects
     for (Int i = 0; i < GlobalCount; i++) {
         Bag p = *GlobalAddr[i];
         if (IS_BAG_REF(p)) {
-            JMark(p);
+            JMark(ptls, p);
         }
     }
 }
@@ -652,10 +632,11 @@ static void GapTaskScanner(jl_task_t * task, int root_task)
             active_start += guardpages_size;
         }
 #endif
+#if !defined(USE_GAP_INSIDE_JULIA)
         if (task == RootTaskOfMainThread) {
             active_end = (char *)GapStackBottom;
         }
-
+#endif
         // Unlike the stack of the current task that we scan in
         // GapRootScanner, we do not know the stack pointer. We
         // therefore use a separate routine that scans from the
@@ -667,19 +648,13 @@ static void GapTaskScanner(jl_task_t * task, int root_task)
 
 UInt TotalGCTime(void)
 {
-    return totalTime;
+    return TotalTime;
 }
 
 static void PreGCHook(int full)
 {
-    // It is possible for the garbage collector to be invoked from a
-    // different thread other than the main thread that is running
-    // GAP. So we save the TLS pointer temporarily and restore it
-    // afterwards. In the long run, JuliaTLS needs to simply become
-    // a thread-local variable.
     FullGC = full;
-    SaveTLS = JuliaTLS;
-    SetJuliaTLS();
+
     // This is the same code as in VarsBeforeCollectBags() for GASMAN.
     // It is necessary because ASS_LVAR() and related functionality
     // does not call CHANGED_BAG() for performance reasons. CHANGED_BAG()
@@ -688,7 +663,7 @@ static void PreGCHook(int full)
     if (STATE(CurrLVars))
         CHANGED_BAG(STATE(CurrLVars));
 
-    startTime = SyTime();
+    StartTime = SyTime();
 
 #ifndef REQUIRE_PRECISE_MARKING
     memset(MarkCache, 0, sizeof(MarkCache));
@@ -700,8 +675,7 @@ static void PreGCHook(int full)
 
 static void PostGCHook(int full)
 {
-    JuliaTLS = SaveTLS;
-    totalTime += SyTime() - startTime;
+    TotalTime += SyTime() - StartTime;
 #ifdef COLLECT_MARK_CACHE_STATS
     /* printf("\n>>>Attempts: %ld\nHit rate: %lf\nCollision rate: %lf\n",
       (long) MarkCacheAttempts,
@@ -723,9 +697,9 @@ static uintptr_t MPtrMarkFunc(jl_ptls_t ptls, jl_value_t * obj)
     // the comments on conservative stack scanning for an in-depth
     // explanation.
     void * ty = jl_typeof(header);
-    if (ty != datatype_bag && ty != datatype_largebag)
+    if (ty != DatatypeSmallBag && ty != DatatypeLargeBag)
         return 0;
-    if (JMark(header))
+    if (JMark(ptls, header))
         return 1;
     return 0;
 }
@@ -737,9 +711,26 @@ static uintptr_t BagMarkFunc(jl_ptls_t ptls, jl_value_t * obj)
     BagHeader * hdr = (BagHeader *)obj;
     Bag         contents = (Bag)(hdr + 1);
     UInt        tnum = hdr->type;
-    YoungRef = 0;
-    TabMarkFuncBags[tnum]((Bag)&contents);
-    return YoungRef;
+    MarkData    ref = { ptls, 0 };
+    TabMarkFuncBags[tnum]((Bag)&contents, &ref);
+    return ref.youngRef;
+}
+
+jl_datatype_t * GAP_DeclareGapObj(jl_sym_t *      name,
+                                  jl_module_t *   module,
+                                  jl_datatype_t * parent)
+{
+    return jl_new_foreign_type(name, module, parent, MPtrMarkFunc, NULL, 1,
+                               0);
+}
+
+jl_datatype_t * GAP_DeclareBag(jl_sym_t *      name,
+                               jl_module_t *   module,
+                               jl_datatype_t * parent,
+                               int             large)
+{
+    return jl_new_foreign_type(name, module, parent, BagMarkFunc, JFinalizer,
+                               1, large > 0);
 }
 
 // Initialize the integration with Julia's garbage collector; in particular,
@@ -751,23 +742,24 @@ static uintptr_t BagMarkFunc(jl_ptls_t ptls, jl_value_t * obj)
 void GAP_InitJuliaMemoryInterface(jl_module_t *   module,
                                   jl_datatype_t * parent)
 {
+    jl_sym_t * name;
+
     // HOOK: initialization happens here.
     for (UInt i = 0; i < NUM_TYPES; i++) {
         TabMarkFuncBags[i] = MarkAllSubBagsDefault;
     }
     // These callbacks need to be set before initialization so
     // that we can track objects allocated during `jl_init()`.
-    max_pool_obj_size = jl_gc_max_internal_obj_size();
+    MaxPoolObjSize = jl_gc_max_internal_obj_size();
     jl_gc_enable_conservative_gc_support();
+#if !defined(USE_GAP_INSIDE_JULIA)
     jl_init();
+#endif
 
-    SetJuliaTLS();
 #ifdef SKIP_GUARD_PAGES
     SetupGuardPagesSize();
 #endif
 
-    is_threaded = jl_n_threads > 1;
-
     // These callbacks potentially require access to the Julia
     // TLS and thus need to be installed after initialization.
     jl_gc_set_cb_root_scanner(GapRootScanner, 1);
@@ -784,42 +776,62 @@ void GAP_InitJuliaMemoryInterface(jl_module_t *   module,
         parent = jl_any_type;
     }
 
+// Julia defines HAVE_JL_REINIT_FOREIGN_TYPE if `jl_reinit_foreign_type`
+// is available.
+#ifdef HAVE_JL_REINIT_FOREIGN_TYPE
+    if (jl_boundp(module, jl_symbol("GapObj"))) {
+        DatatypeGapObj =
+            (jl_datatype_t *)jl_get_global(module, jl_symbol("GapObj"));
+        jl_reinit_foreign_type(DatatypeGapObj, MPtrMarkFunc, NULL);
+
+        DatatypeSmallBag =
+            (jl_datatype_t *)jl_get_global(module, jl_symbol("SmallBag"));
+        jl_reinit_foreign_type(DatatypeSmallBag, BagMarkFunc, JFinalizer);
+
+        DatatypeLargeBag =
+            (jl_datatype_t *)jl_get_global(module, jl_symbol("LargeBag"));
+        jl_reinit_foreign_type(DatatypeLargeBag, BagMarkFunc, JFinalizer);
+
+        return;
+    }
+#endif
+
     // create and store data type for master pointers
-    datatype_mptr = jl_new_foreign_type(jl_symbol("GapObj"), module, parent,
-                                        MPtrMarkFunc, NULL, 1, 0);
-    GAP_ASSERT(jl_is_datatype(datatype_mptr));
-    jl_set_const(module, jl_symbol("GapObj"), (jl_value_t *)datatype_mptr);
+    name = jl_symbol("GapObj");
+    DatatypeGapObj = GAP_DeclareGapObj(name, module, parent);
+    GAP_ASSERT(jl_is_datatype(DatatypeGapObj));
+    jl_set_const(module, name, (jl_value_t *)DatatypeGapObj);
 
     // create and store data type for small bags
-    datatype_bag = jl_new_foreign_type(jl_symbol("Bag"), module, jl_any_type,
-                                       BagMarkFunc, JFinalizer, 1, 0);
-    GAP_ASSERT(jl_is_datatype(datatype_bag));
-    jl_set_const(module, jl_symbol("Bag"), (jl_value_t *)datatype_bag);
+    name = jl_symbol("SmallBag");
+    DatatypeSmallBag = GAP_DeclareBag(name, module, jl_any_type, 0);
+    GAP_ASSERT(jl_is_datatype(DatatypeSmallBag));
+    jl_set_const(module, name, (jl_value_t *)DatatypeSmallBag);
 
     // create and store data type for large bags
-    datatype_largebag =
-        jl_new_foreign_type(jl_symbol("LargeBag"), module, jl_any_type,
-                            BagMarkFunc, JFinalizer, 1, 1);
-    GAP_ASSERT(jl_is_datatype(datatype_largebag));
-    jl_set_const(module, jl_symbol("LargeBag"),
-                 (jl_value_t *)datatype_largebag);
-
+    name = jl_symbol("LargeBag");
+    DatatypeLargeBag = GAP_DeclareBag(name, module, jl_any_type, 1);
+    GAP_ASSERT(jl_is_datatype(DatatypeLargeBag));
+    jl_set_const(module, name, (jl_value_t *)DatatypeLargeBag);
 }
 
 void InitBags(UInt initial_size, Bag * stack_bottom)
 {
-    GapStackBottom = stack_bottom;
-    totalTime = 0;
+    TotalTime = 0;
 
-    if (!datatype_mptr) {
+    if (!DatatypeGapObj) {
         GAP_InitJuliaMemoryInterface(0, 0);
     }
 
+#if !defined(USE_GAP_INSIDE_JULIA)
+    GapStackBottom = stack_bottom;
+
     // If we are embedding Julia in GAP, remember the root task
     // of the main thread. The extent of the stack buffer of that
     // task is calculated a bit differently than for other tasks.
     if (!IsUsingLibGap())
         RootTaskOfMainThread = (jl_task_t *)jl_get_current_task();
+#endif
 }
 
 UInt CollectBags(UInt size, UInt full)
@@ -839,7 +851,7 @@ void RetypeBagIntern(Bag bag, UInt new_type)
         return;
 
 #ifdef COUNT_BAGS
-    /* update the statistics      */
+    // update the statistics
     {
         UInt size;
 
@@ -880,7 +892,7 @@ void RetypeBagIntern(Bag bag, UInt new_type)
 
 Bag NewBag(UInt type, UInt size)
 {
-    Bag  bag; /* identifier of the new bag       */
+    Bag  bag; // identifier of the new bag
     UInt alloc_size;
 
     alloc_size = sizeof(BagHeader) + size;
@@ -898,12 +910,12 @@ Bag NewBag(UInt type, UInt size)
     if (size == 0)
         alloc_size++;
 
-    if (is_threaded)
-        SetJuliaTLS();
-    bag = jl_gc_alloc_typed(JuliaTLS, sizeof(void *), datatype_mptr);
+    jl_ptls_t ptls = jl_get_ptls_states();
+
+    bag = jl_gc_alloc_typed(ptls, sizeof(void *), DatatypeGapObj);
     SET_PTR_BAG(bag, 0);
 
-    BagHeader * header = AllocateBagMemory(type, alloc_size);
+    BagHeader * header = AllocateBagMemory(ptls, type, alloc_size);
 
     header->type = type;
     header->flags = 0;
@@ -938,7 +950,7 @@ UInt ResizeBag(Bag bag, UInt new_size)
             alloc_size++;
 
         // allocate new bag
-        header = AllocateBagMemory(header->type, alloc_size);
+        header = AllocateBagMemory(jl_get_ptls_states(), header->type, alloc_size);
 
         // copy bag header and data, and update size
         memcpy(header, BAG_HEADER(bag), sizeof(BagHeader) + old_size);
@@ -973,7 +985,7 @@ void SwapMasterPoint(Bag bag1, Bag bag2)
 
 // HOOK: mark functions
 
-inline void MarkBag(Bag bag)
+inline void MarkBag(Bag bag, void * ref)
 {
     if (!IS_BAG_REF(bag))
         return;
@@ -1006,29 +1018,29 @@ inline void MarkBag(Bag bag)
     // relies on Julia internals. It is functionally equivalent
     // to:
     //
-    //     if (JMarkTyped(p, datatype_mptr)) YoungRef++;
+    //     if (JMarkTyped(p, DatatypeGapObj)) ((MarkData *)ref)->youngRef++;
     //
     switch (jl_astaggedvalue(p)->bits.gc) {
     case 0:
-        if (JMarkTyped(p, datatype_mptr))
-            YoungRef++;
+        if (JMarkTyped(((MarkData *)ref)->ptls, p, DatatypeGapObj))
+            ((MarkData *)ref)->youngRef++;
         break;
     case 1:
-        YoungRef++;
+        ((MarkData *)ref)->youngRef++;
         break;
     case 2:
-        JMarkTyped(p, datatype_mptr);
+        JMarkTyped(((MarkData *)ref)->ptls, p, DatatypeGapObj);
         break;
     case 3:
         break;
     }
 }
 
-void MarkJuliaWeakRef(void * p)
+void MarkJuliaWeakRef(void * p, void * ref)
 {
     // If `jl_nothing` gets passed in as an argument, it will not
     // be marked. This is harmless, because `jl_nothing` will always
     // be live regardless.
-    if (JMarkTyped(p, jl_weakref_type))
-        YoungRef++;
+    if (JMarkTyped(((MarkData *)ref)->ptls, p, jl_weakref_type))
+        ((MarkData *)ref)->youngRef++;
 }
