@@ -137,7 +137,7 @@ Obj READ_ALL_COMMANDS(Obj instream, Obj echo, Obj capture, Obj resultCallback)
 
     RequireInputStream("READ_ALL_COMMANDS", instream);
 
-    /* try to open the streams */
+    // try to open the streams
     TypInputFile input;
     if (!OpenInputStream(&input, instream, echo == True)) {
         return Fail;
@@ -285,19 +285,19 @@ static void READ_INNER(TypInputFile * input)
       }
     AssGVarWithoutReadOnlyCheck( LastReadValueGVar, 0);
 
-    /* now do the reading                                                  */
+    // now do the reading
     while ( 1 ) {
         Obj evalResult;
         ExecStatus status = ReadEvalCommand(0, input, &evalResult, 0);
         if (STATE(UserHasQuit) || STATE(UserHasQUIT))
             break;
 
-        /* handle return-value or return-void command                      */
+        // handle return-value or return-void command
         if (status == STATUS_RETURN) {
             Pr("'return' must not be used in file read-eval loop\n", 0, 0);
         }
 
-        /* handle quit command or <end-of-file>                            */
+        // handle quit command or <end-of-file>
         else if (status == STATUS_EOF || status == STATUS_ERROR)
           break;
         else if (status == STATUS_QUIT) {
@@ -312,7 +312,7 @@ static void READ_INNER(TypInputFile * input)
           {
             AssGVarWithoutReadOnlyCheck( LastReadValueGVar, evalResult);
           }
-        
+
     }
 }
 
@@ -325,14 +325,14 @@ static void READ_INNER(TypInputFile * input)
 */
 Obj READ_AS_FUNC(TypInputFile * input)
 {
-    /* now do the reading                                                  */
+    // now do the reading
     Obj evalResult;
     ExecStatus status = ReadEvalFile(input, &evalResult);
 
-    /* get the function                                                    */
+    // get the function
     Obj func = (status == STATUS_END) ? evalResult : Fail;
 
-    /* return the function                                                 */
+    // return the function
     return func;
 }
 
@@ -654,7 +654,7 @@ static Obj FuncPrint(Obj self, Obj args)
     volatile Obj        arg;
     volatile UInt       i;
 
-    /* print all the arguments, take care of strings and functions         */
+    // print all the arguments, take care of strings and functions
     for ( i = 1;  i <= LEN_PLIST(args);  i++ ) {
         arg = ELM_LIST(args,i);
         if ( IS_PLIST(arg) && 0 < LEN_PLIST(arg) && IsStringConv(arg) ) {
@@ -678,12 +678,12 @@ static Obj PRINT_OR_APPEND_TO_FILE_OR_STREAM(Obj args, int append, int file)
     volatile Obj        destination;
     volatile UInt       i;
 
-    /* first entry is the file or stream                                   */
+    // first entry is the file or stream
     destination = ELM_LIST(args, 1);
 
     TypOutputFile output;
 
-    /* try to open the output and handle failures                          */
+    // try to open the output and handle failures
     if (file) {
         RequireStringRep(funcname, destination);
         i = OpenOutput(&output, CONST_CSTR_STRING(destination), append);
@@ -706,11 +706,11 @@ static Obj PRINT_OR_APPEND_TO_FILE_OR_STREAM(Obj args, int append, int file)
         }
     }
 
-    /* print all the arguments, take care of strings and functions         */
+    // print all the arguments, take care of strings and functions
     for ( i = 2;  i <= LEN_PLIST(args);  i++ ) {
         arg = ELM_LIST(args,i);
 
-        /* if an error occurs stop printing                                */
+        // if an error occurs stop printing
         GAP_TRY
         {
             if (IS_PLIST(arg) && 0 < LEN_PLIST(arg) && IsStringConv(arg)) {
@@ -730,7 +730,7 @@ static Obj PRINT_OR_APPEND_TO_FILE_OR_STREAM(Obj args, int append, int file)
         }
     }
 
-    /* close the output file again, and return nothing                     */
+    // close the output file again, and return nothing
     if (!CloseOutput(&output)) {
         ErrorQuit("%s: cannot close output", (Int)funcname, 0);
     }
@@ -815,34 +815,6 @@ static Obj FuncREAD(Obj self, Obj inputObj)
 }
 
 
-/****************************************************************************
-**
-*F  FuncREAD_NORECOVERY( <self>, <input> ) . . .  . . . read a file or stream
-**
-**  Read the current input and close the input stream. Disable the normal
-**  mechanism which ensures that quitting from a break loop gets you back to
-**  a live prompt. This is initially designed for the files read from the
-**  command line.
-*/
-static Obj FuncREAD_NORECOVERY(Obj self, Obj inputObj)
-{
-    TypInputFile input;
-    if (!OpenInputFileOrStream(SELF_NAME, &input, inputObj))
-        return False;
-
-    // read the file
-    READ_INNER(&input);
-    if (!CloseInput(&input)) {
-        ErrorQuit("Panic: READ_NORECOVERY cannot close input", 0, 0);
-    }
-    if (STATE(UserHasQuit)) {
-        STATE(UserHasQuit) = FALSE;    // stop recovery here
-        return Fail;
-    }
-    return True;
-}
-
-
 /****************************************************************************
 **
 *F  FuncREAD_STREAM_LOOP( <self>, <instream>, <outstream> ) . . read a stream
@@ -960,9 +932,9 @@ static Obj FuncREAD_GAP_ROOT(Obj self, Obj filename)
 
     RequireStringRep(SELF_NAME, filename);
 
-    /* Copy to avoid garbage collection moving string                      */
+    // Copy to avoid garbage collection moving string
     gap_strlcpy(filenamecpy, CONST_CSTR_STRING(filename), GAP_PATH_MAX);
-    /* try to open the file                                                */
+    // try to open the file
     return READ_GAP_ROOT(filenamecpy) ? True : False;
 }
 
@@ -1035,7 +1007,7 @@ static Obj FuncRemoveFile(Obj self, Obj filename)
 {
     RequireStringRep(SELF_NAME, filename);
 
-    /* call the system dependent function                                  */
+    // call the system dependent function
     return SyRemoveFile( CONST_CSTR_STRING(filename) ) == -1 ? Fail : True;
 }
 
@@ -1047,7 +1019,7 @@ static Obj FuncCreateDir(Obj self, Obj filename)
 {
     RequireStringRep(SELF_NAME, filename);
 
-    /* call the system dependent function                                  */
+    // call the system dependent function
     return SyMkdir( CONST_CSTR_STRING(filename) ) == -1 ? Fail : True;
 }
 
@@ -1059,23 +1031,54 @@ static Obj FuncRemoveDir(Obj self, Obj filename)
 {
     RequireStringRep(SELF_NAME, filename);
 
-    /* call the system dependent function                                  */
+    // call the system dependent function
     return SyRmdir( CONST_CSTR_STRING(filename) ) == -1 ? Fail : True;
 }
 
 /****************************************************************************
 **
-*F  FuncIsDir( <self>, <name> )  . . . . . check whether something is a dir
+*F  FuncIS_DIR( <self>, <path> )  . . . . . check whether something is a dir
 */
-static Obj FuncIsDir(Obj self, Obj filename)
+static Obj FuncIS_DIR(Obj self, Obj path)
 {
-    RequireStringRep(SELF_NAME, filename);
+    RequireStringRep(SELF_NAME, path);
 
-    /* call the system dependent function                                  */
-    return SyIsDir( CONST_CSTR_STRING(filename) );
+    // call the system dependent function
+    return SyFileType(CONST_CSTR_STRING(path)) == 'D' ? True : False;
 }
 
+/****************************************************************************
+**
+*F  FuncGAP_getcwd( <self> ) . . . . . . . . . get working directory pathname
+*/
+static Obj FuncGAP_getcwd(Obj self)
+{
+    char * res;
+    char   buf[GAP_PATH_MAX];
 
+    res = getcwd(buf, sizeof(buf));
+    if (res == NULL) {
+        SySetErrorNo();
+        return Fail;
+    }
+    return MakeImmString(buf);
+}
+
+/****************************************************************************
+**
+*F  FuncGAP_chdir( <self>, <path> ) . . . .  change current working directory
+*/
+static Obj FuncGAP_chdir(Obj self, Obj path)
+{
+    RequireStringRep(SELF_NAME, path);
+
+    int res = chdir(CONST_CSTR_STRING(path));
+    if (res < 0) {
+        SySetErrorNo();
+        return Fail;
+    }
+    return True;
+}
 
 
 /****************************************************************************
@@ -1096,24 +1099,24 @@ static Obj FuncLastSystemError(Obj self)
     Obj             err;
     Obj             msg;
 
-    /* constructed an error record                                         */
+    // constructed an error record
     err = NEW_PREC(0);
 
-    /* check if an errors has occurred                                     */
+    // check if an errors has occurred
     if ( SyLastErrorNo != 0 ) {
         ASS_REC( err, ErrorNumberRNam, INTOBJ_INT(SyLastErrorNo) );
         msg = MakeString(SyLastErrorMessage);
         ASS_REC( err, ErrorMessageRNam, msg );
     }
 
-    /* no error has occurred                                               */
+    // no error has occurred
     else {
         ASS_REC( err, ErrorNumberRNam, INTOBJ_INT(0) );
         msg = MakeString("no error");
         ASS_REC( err, ErrorMessageRNam, msg );
     }
 
-    /* return the error record                                             */
+    // return the error record
     return err;
 }
 
@@ -1128,7 +1131,7 @@ static Obj FuncIsExistingFile(Obj self, Obj filename)
 
     RequireStringRep(SELF_NAME, filename);
 
-    /* call the system dependent function                                  */
+    // call the system dependent function
     res = SyIsExistingFile( CONST_CSTR_STRING(filename) );
     return res == -1 ? False : True;
 }
@@ -1144,7 +1147,7 @@ static Obj FuncIsReadableFile(Obj self, Obj filename)
 
     RequireStringRep(SELF_NAME, filename);
 
-    /* call the system dependent function                                  */
+    // call the system dependent function
     res = SyIsReadableFile( CONST_CSTR_STRING(filename) );
     return res == -1 ? False : True;
 }
@@ -1160,7 +1163,7 @@ static Obj FuncIsWritableFile(Obj self, Obj filename)
 
     RequireStringRep(SELF_NAME, filename);
 
-    /* call the system dependent function                                  */
+    // call the system dependent function
     res = SyIsWritableFile( CONST_CSTR_STRING(filename) );
     return res == -1 ? False : True;
 }
@@ -1176,7 +1179,7 @@ static Obj FuncIsExecutableFile(Obj self, Obj filename)
 
     RequireStringRep(SELF_NAME, filename);
 
-    /* call the system dependent function                                  */
+    // call the system dependent function
     res = SyIsExecutableFile( CONST_CSTR_STRING(filename) );
     return res == -1 ? False : True;
 }
@@ -1192,7 +1195,7 @@ static Obj FuncIsDirectoryPathString(Obj self, Obj filename)
 
     RequireStringRep(SELF_NAME, filename);
 
-    /* call the system dependent function                                  */
+    // call the system dependent function
     res = SyIsDirectoryPath( CONST_CSTR_STRING(filename) );
     return res == -1 ? False : True;
 }
@@ -1243,8 +1246,8 @@ static Obj FuncLIST_DIR(Obj self, Obj dirname)
 static Obj FuncCLOSE_FILE(Obj self, Obj fid)
 {
     Int ifid = GetSmallInt(SELF_NAME, fid);
-    
-    /* call the system dependent function                                  */
+
+    // call the system dependent function
     Int ret = SyFclose( ifid );
     return ret == -1 ? Fail : True;
 }
@@ -1260,7 +1263,7 @@ static Obj FuncINPUT_TEXT_FILE(Obj self, Obj filename)
 
     RequireStringRep(SELF_NAME, filename);
 
-    /* call the system dependent function                                  */
+    // call the system dependent function
     SyClearErrorNo();
     fid = SyFopen(CONST_CSTR_STRING(filename), "r", TRUE);
     if (fid == -1)
@@ -1276,7 +1279,7 @@ static Obj FuncINPUT_TEXT_FILE(Obj self, Obj filename)
 static Obj FuncIS_END_OF_FILE(Obj self, Obj fid)
 {
     Int ifid = GetSmallInt(SELF_NAME, fid);
-    
+
     Int ret = SyIsEndOfFile( ifid );
     return ret == -1 ? Fail : ( ret == 0 ? False : True );
 }
@@ -1295,7 +1298,7 @@ static Obj FuncOUTPUT_TEXT_FILE(Obj self, Obj filename, Obj append, Obj comp)
     RequireTrueOrFalse(SELF_NAME, comp);
 
     Int compbool = (comp == True);
-    /* call the system dependent function                                  */
+    // call the system dependent function
     SyClearErrorNo();
     if ( append == True ) {
         fid = SyFopen(CONST_CSTR_STRING(filename), "a", compbool);
@@ -1337,8 +1340,8 @@ static Obj FuncPOSITION_FILE(Obj self, Obj fid)
 static Obj FuncREAD_BYTE_FILE(Obj self, Obj fid)
 {
     Int ifid = GetSmallInt(SELF_NAME, fid);
-    
-    /* call the system dependent function                                  */
+
+    // call the system dependent function
     Int ret = SyGetch( ifid );
 
     return ret == EOF ? Fail : INTOBJ_INT(ret);
@@ -1348,7 +1351,7 @@ static Obj FuncREAD_BYTE_FILE(Obj self, Obj fid)
 /****************************************************************************
 **
 *F  FuncREAD_LINE_FILE( <self>, <fid> ) . . . . . . . . . . . . . read a line
-**  
+**
 **  This uses fgets and works only if there are no zero characters in <fid>.
 */
 static Obj FuncREAD_LINE_FILE(Obj self, Obj fid)
@@ -1361,8 +1364,8 @@ static Obj FuncREAD_LINE_FILE(Obj self, Obj fid)
 
     Int ifid = GetSmallInt(SELF_NAME, fid);
 
-    /* read <fid> until we see a newline or eof or we've read at least
-       one byte and more are not immediately available */
+    // read <fid> until we see a newline or eof or we've read at least
+    // one byte and more are not immediately available
     str = NEW_STRING(0);
     len = 0;
     while (1) {
@@ -1381,19 +1384,19 @@ static Obj FuncREAD_LINE_FILE(Obj self, Obj fid)
         break;
     }
 
-    /* fix the length of <str>                                             */
+    // fix the length of <str>
     len = GET_LEN_STRING(str);
     ResizeBag( str, SIZEBAG_STRINGLEN(len) );
 
-    /* and return                                                          */
+    // and return
     return len == 0 ? Fail : str;
 }
 
 /****************************************************************************
 **
 *F  FuncREAD_ALL_FILE( <self>, <fid>, <limit> )  . . . . . . . read remainder
-**  
-** more precisely, read until either
+**
+**  more precisely, read until either
 **   (a) we have read at least one byte and no more are available
 **   (b) we have evidence that it will never be possible to read a byte
 **   (c) we have read <limit> bytes (-1 indicates no limit)
@@ -1456,10 +1459,10 @@ static Obj FuncREAD_ALL_FILE(Obj self, Obj fid, Obj limit)
       SET_LEN_STRING(str, len);
     }
 
-    /* fix the length of <str>                                             */
+    // fix the length of <str>
     len = GET_LEN_STRING(str);
 #ifdef SYS_IS_CYGWIN32
-    /* line end hackery */
+    // line end hackery
     UInt i = 0, j = 0;
     while (i < len) {
         if (CHARS_STRING(str)[i] == '\r') {
@@ -1480,7 +1483,7 @@ static Obj FuncREAD_ALL_FILE(Obj self, Obj fid, Obj limit)
 #endif
     ResizeBag( str, SIZEBAG_STRINGLEN(len) );
 
-    /* and return                                                          */
+    // and return
     return len == 0 ? Fail : str;
 }
 
@@ -1494,7 +1497,7 @@ static Obj FuncSEEK_POSITION_FILE(Obj self, Obj fid, Obj pos)
 
     Int ifid = GetSmallInt(SELF_NAME, fid);
     Int ipos = GetSmallInt(SELF_NAME, pos);
-    
+
     ret = SyFseek( ifid, ipos );
     return ret == -1 ? Fail : True;
 }
@@ -1508,8 +1511,8 @@ static Obj FuncWRITE_BYTE_FILE(Obj self, Obj fid, Obj ch)
 {
     Int ifid = GetSmallInt(SELF_NAME, fid);
     Int ich = GetSmallInt(SELF_NAME, ch);
-    
-    /* call the system dependent function                                  */
+
+    // call the system dependent function
     Int ret = SyEchoch( ich, ifid );
     return ret == -1 ? Fail : True;
 }
@@ -1523,10 +1526,10 @@ static Obj FuncWRITE_STRING_FILE_NC(Obj self, Obj fid, Obj str)
     Int             len = 0, l, ret;
     const char      *ptr;
 
-    /* don't check the argument                                            */
+    // don't check the argument
     RequireStringRep(SELF_NAME, str);
 
-    
+
     len = GET_LEN_STRING(str);
     ptr = CONST_CSTR_STRING(str);
     while (len > 0) {
@@ -1594,34 +1597,34 @@ static Obj FuncUNIXSelect(Obj self,
   FD_ZERO(&outfds);
   FD_ZERO(&excfds);
   maxfd = 0;
-  /* Handle input file descriptors: */
+  // Handle input file descriptors:
   for (i = 1;i <= LEN_PLIST(inlist);i++) {
     o = ELM_PLIST(inlist,i);
     if (o != (Obj) 0 && IS_INTOBJ(o)) {
-      j = INT_INTOBJ(o);  /* a UNIX file descriptor */
+      j = INT_INTOBJ(o);  // a UNIX file descriptor
       FD_SET(j,&infds);
       if (j > maxfd) maxfd = j;
     }
   }
-  /* Handle output file descriptors: */
+  // Handle output file descriptors:
   for (i = 1;i <= LEN_PLIST(outlist);i++) {
     o = ELM_PLIST(outlist,i);
     if (o != (Obj) 0 && IS_INTOBJ(o)) {
-      j = INT_INTOBJ(o);  /* a UNIX file descriptor */
+      j = INT_INTOBJ(o);  // a UNIX file descriptor
       FD_SET(j,&outfds);
       if (j > maxfd) maxfd = j;
     }
   }
-  /* Handle exception file descriptors: */
+  // Handle exception file descriptors:
   for (i = 1;i <= LEN_PLIST(exclist);i++) {
     o = ELM_PLIST(exclist,i);
     if (o != (Obj) 0 && IS_INTOBJ(o)) {
-      j = INT_INTOBJ(o);  /* a UNIX file descriptor */
+      j = INT_INTOBJ(o);  // a UNIX file descriptor
       FD_SET(j,&excfds);
       if (j > maxfd) maxfd = j;
     }
   }
-  /* Handle the timeout: */
+  // Handle the timeout:
   if (timeoutsec != (Obj) 0 && IS_INTOBJ(timeoutsec) &&
       timeoutusec != (Obj) 0 && IS_INTOBJ(timeoutusec)) {
     tv.tv_sec = INT_INTOBJ(timeoutsec);
@@ -1630,36 +1633,36 @@ static Obj FuncUNIXSelect(Obj self,
   } else {
     n = select(maxfd+1,&infds,&outfds,&excfds,NULL);
   }
-    
+
   if (n >= 0) {
-    /* Now run through the lists and call functions if ready: */
+    // Now run through the lists and call functions if ready:
 
     for (i = 1;i <= LEN_PLIST(inlist);i++) {
       o = ELM_PLIST(inlist,i);
       if (o != (Obj) 0 && IS_INTOBJ(o)) {
-        j = INT_INTOBJ(o);  /* a UNIX file descriptor */
+        j = INT_INTOBJ(o);  // a UNIX file descriptor
         if (!(FD_ISSET(j,&infds))) {
           SET_ELM_PLIST(inlist,i,Fail);
           CHANGED_BAG(inlist);
         }
       }
     }
-    /* Handle output file descriptors: */
+    // Handle output file descriptors:
     for (i = 1;i <= LEN_PLIST(outlist);i++) {
       o = ELM_PLIST(outlist,i);
       if (o != (Obj) 0 && IS_INTOBJ(o)) {
-        j = INT_INTOBJ(o);  /* a UNIX file descriptor */
+        j = INT_INTOBJ(o);  // a UNIX file descriptor
         if (!(FD_ISSET(j,&outfds))) {
           SET_ELM_PLIST(outlist,i,Fail);
           CHANGED_BAG(outlist);
         }
       }
     }
-    /* Handle exception file descriptors: */
+    // Handle exception file descriptors:
     for (i = 1;i <= LEN_PLIST(exclist);i++) {
       o = ELM_PLIST(exclist,i);
       if (o != (Obj) 0 && IS_INTOBJ(o)) {
-        j = INT_INTOBJ(o);  /* a UNIX file descriptor */
+        j = INT_INTOBJ(o);  // a UNIX file descriptor
         if (!(FD_ISSET(j,&excfds))) {
           SET_ELM_PLIST(exclist,i,Fail);
           CHANGED_BAG(exclist);
@@ -1671,60 +1674,6 @@ static Obj FuncUNIXSelect(Obj self,
 }
 #endif
 
-/****************************************************************************
-**
-*F * * * * * * * * * * * * * execution functions  * * * * * * * * * * * * * *
-*/
-
-
-/****************************************************************************
-**
-*F  FuncExecuteProcess( <self>, <dir>, <prg>, <in>, <out>, <args> )   process
-*/
-static Obj
-FuncExecuteProcess(Obj self, Obj dir, Obj prg, Obj in, Obj out, Obj args)
-{
-    Obj    ExecArgs[1024];
-    Char * ExecCArgs[1024];
-
-    Obj                 tmp;
-    Int                 res;
-    Int                 i;
-
-    RequireStringRep(SELF_NAME, dir);
-    RequireStringRep(SELF_NAME, prg);
-    Int iin = GetSmallInt(SELF_NAME, in);
-    Int iout = GetSmallInt(SELF_NAME, out);
-    RequireSmallList(SELF_NAME, args);
-
-    /* create an argument array                                            */
-    for ( i = 1;  i <= LEN_LIST(args);  i++ ) {
-        if ( i == 1023 )
-            break;
-        tmp = ELM_LIST( args, i );
-        RequireStringRep(SELF_NAME, tmp);
-        ExecArgs[i] = tmp;
-    }
-    ExecCArgs[0]   = CSTR_STRING(prg);
-    ExecCArgs[i] = 0;
-    for ( i--;  0 < i;  i-- ) {
-        ExecCArgs[i] = CSTR_STRING(ExecArgs[i]);
-    }
-    if (SyWindow && out == INTOBJ_INT(1)) /* standard output */
-      syWinPut( INT_INTOBJ(out), "@z","");
-
-    /* execute the process                                                 */
-    res = SyExecuteProcess( CSTR_STRING(dir),
-                            CSTR_STRING(prg),
-                            iin,
-                            iout,
-                            ExecCArgs );
-
-    if (SyWindow && out == INTOBJ_INT(1)) /* standard output */
-      syWinPut( INT_INTOBJ(out), "@mAgIc","");
-    return res == 255 ? Fail : INTOBJ_INT(res);
-}
-
 
 /****************************************************************************
 **
@@ -1738,7 +1687,6 @@ FuncExecuteProcess(Obj self, Obj dir, Obj prg, Obj in, Obj out, Obj args)
 static StructGVarFunc GVarFuncs[] = {
 
     GVAR_FUNC_1ARGS(READ, input),
-    GVAR_FUNC_1ARGS(READ_NORECOVERY, input),
     GVAR_FUNC_4ARGS(
         READ_ALL_COMMANDS, instream, echo, capture, resultCallback),
     GVAR_FUNC_2ARGS(READ_COMMAND_REAL, stream, echo),
@@ -1765,7 +1713,9 @@ static StructGVarFunc GVarFuncs[] = {
     GVAR_FUNC_1ARGS(RemoveFile, filename),
     GVAR_FUNC_1ARGS(CreateDir, filename),
     GVAR_FUNC_1ARGS(RemoveDir, filename),
-    GVAR_FUNC_1ARGS(IsDir, filename),
+    GVAR_FUNC_1ARGS(IS_DIR, path),
+    GVAR_FUNC_0ARGS(GAP_getcwd),
+    GVAR_FUNC_1ARGS(GAP_chdir, path),
     GVAR_FUNC_0ARGS(LastSystemError),
     GVAR_FUNC_1ARGS(IsExistingFile, filename),
     GVAR_FUNC_1ARGS(IsReadableFile, filename),
@@ -1793,7 +1743,6 @@ static StructGVarFunc GVarFuncs[] = {
     GVAR_FUNC_5ARGS(
         UNIXSelect, inlist, outlist, exclist, timeoutsec, timeoutusec),
 #endif
-    GVAR_FUNC_5ARGS(ExecuteProcess, dir, prg, in, out, args),
     { 0, 0, 0, 0, 0 }
 
 };
@@ -1806,7 +1755,7 @@ static StructGVarFunc GVarFuncs[] = {
 static Int InitKernel (
     StructInitInfo *    module )
 {
-    /* init filters and functions                                          */
+    // init filters and functions
     InitHdlrFuncsFromTable( GVarFuncs );
 
     ImportFuncFromLibrary( "IsInputStream", &IsInputStream );
@@ -1823,11 +1772,11 @@ static Int InitKernel (
 static Int PostRestore (
     StructInitInfo *    module )
 {
-    /* file access test functions                                          */
+    // file access test functions
     ErrorNumberRNam  = RNamName("number");
     ErrorMessageRNam = RNamName("message");
 
-    /* pick up the number of this global */
+    // pick up the number of this global
     LastReadValueGVar = GVarName("LastReadValue");
 
     return 0;
@@ -1841,7 +1790,7 @@ static Int PostRestore (
 static Int InitLibrary (
     StructInitInfo *    module )
 {
-    /* init filters and functions                                          */
+    // init filters and functions
     InitGVarFuncsFromTable( GVarFuncs );
 
 
